@@ -162,7 +162,6 @@ class QuickBooks(object):
         }
 
         if file_path:
-            attachment = open(file_path, 'rb')
             url = url.replace('attachable', 'upload')
             boundary = '-------------PythonMultipartPost'
             headers.update({
@@ -173,7 +172,8 @@ class QuickBooks(object):
                 'Connection': 'close'
             })
 
-            binary_data = str(base64.b64encode(attachment.read()).decode('ascii'))
+            with open(file_path, 'rb') as attachment:
+                binary_data = str(base64.b64encode(attachment.read()).decode('ascii'))
 
             content_type = json.loads(request_body)['ContentType']
 
